# CSFlow

## Original code

[https://github.com/MasterHow/CSFlow](https://github.com/MasterHow/CSFlow)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@article{shi2022csflow,
  title={CSFlow: Learning optical flow via cross strip correlation for autonomous driving},
  author={Shi, Hao and Zhou, Yifan and Yang, Kailun and Yin, Xiaoting and Wang, Kaiwei},
  journal={arXiv preprint arXiv:2202.00909},
  year={2022}
}
```